@@ -87,7 +87,10 @@ class DefaultQueryIterator(QueryIterator):
             elif "beir" in topics_path:
                 topics = get_topics_with_reader('io.anserini.search.topicreader.TsvStringTopicReader', topics_path)
             elif topics_path.endswith('.tsv') or topics_path.endswith('.tsv.gz'):
-                topics = get_topics_with_reader('io.anserini.search.topicreader.TsvIntTopicReader', topics_path)
+                try:
+                    topics = get_topics_with_reader('io.anserini.search.topicreader.TsvIntTopicReader', topics_path)
+                except ValueError as e:
+                    topics = get_topics_with_reader('io.anserini.search.topicreader.TsvStringTopicReader', topics_path)
             elif topics_path.endswith('.trec'):
                 topics = get_topics_with_reader('io.anserini.search.topicreader.TrecTopicReader', topics_path)
             elif 'cacm' in topics_path:
