@@ -257,18 +257,29 @@ topics_mapping = {
     'hc4-v1.0-zh-en-test-title': JTopics.HC4_V1_0_ZH_EN_TEST_TITLE,
     'hc4-v1.0-zh-en-test-desc': JTopics.HC4_V1_0_ZH_EN_TEST_DESC,
     'hc4-v1.0-zh-en-test-desc-title': JTopics.HC4_V1_0_ZH_EN_TEST_DESC_TITLE,
-    'neuclir22-en-title': JTopics.NEUCLIR22_EN_TITLE,
-    'neuclir22-en-desc': JTopics.NEUCLIR22_EN_DESC,
-    'neuclir22-en-desc-title': JTopics.NEUCLIR22_EN_DESC_TITLE,
-    'neuclir22-fa-title': JTopics.NEUCLIR22_FA_TITLE,
-    'neuclir22-fa-desc': JTopics.NEUCLIR22_FA_DESC,
-    'neuclir22-fa-desc-title': JTopics.NEUCLIR22_FA_DESC_TITLE,
-    'neuclir22-ru-title': JTopics.NEUCLIR22_RU_TITLE,
-    'neuclir22-ru-desc': JTopics.NEUCLIR22_RU_DESC,
-    'neuclir22-ru-desc-title': JTopics.NEUCLIR22_RU_DESC_TITLE,
-    'neuclir22-zh-title': JTopics.NEUCLIR22_ZH_TITLE,
-    'neuclir22-zh-desc': JTopics.NEUCLIR22_ZH_DESC,
-    'neuclir22-zh-desc-title': JTopics.NEUCLIR22_ZH_DESC_TITLE,
+    # NeuCLIR 2022 topics
+    'neuclir22-en-title':         JTopics.NEUCLIR22_EN_TITLE,
+    'neuclir22-en-desc':          JTopics.NEUCLIR22_EN_DESC,
+    'neuclir22-en-desc-title':    JTopics.NEUCLIR22_EN_DESC_TITLE,
+    'neuclir22-fa-ht-title':      JTopics.NEUCLIR22_FA_HT_TITLE,
+    'neuclir22-fa-ht-desc':       JTopics.NEUCLIR22_FA_HT_DESC,
+    'neuclir22-fa-ht-desc-title': JTopics.NEUCLIR22_FA_HT_DESC_TITLE,
+    'neuclir22-fa-mt-title':      JTopics.NEUCLIR22_FA_MT_TITLE,
+    'neuclir22-fa-mt-desc':       JTopics.NEUCLIR22_FA_MT_DESC,
+    'neuclir22-fa-mt-desc-title': JTopics.NEUCLIR22_FA_MT_DESC_TITLE,
+    'neuclir22-ru-ht-title':      JTopics.NEUCLIR22_RU_HT_TITLE,
+    'neuclir22-ru-ht-desc':       JTopics.NEUCLIR22_RU_HT_DESC,
+    'neuclir22-ru-ht-desc-title': JTopics.NEUCLIR22_RU_HT_DESC_TITLE,
+    'neuclir22-ru-mt-title':      JTopics.NEUCLIR22_RU_MT_TITLE,
+    'neuclir22-ru-mt-desc':       JTopics.NEUCLIR22_RU_MT_DESC,
+    'neuclir22-ru-mt-desc-title': JTopics.NEUCLIR22_RU_MT_DESC_TITLE,
+    'neuclir22-zh-ht-title':      JTopics.NEUCLIR22_ZH_HT_TITLE,
+    'neuclir22-zh-ht-desc':       JTopics.NEUCLIR22_ZH_HT_DESC,
+    'neuclir22-zh-ht-desc-title': JTopics.NEUCLIR22_ZH_HT_DESC_TITLE,
+    'neuclir22-zh-mt-title':      JTopics.NEUCLIR22_ZH_MT_TITLE,
+    'neuclir22-zh-mt-desc':       JTopics.NEUCLIR22_ZH_MT_DESC,
+    'neuclir22-zh-mt-desc-title': JTopics.NEUCLIR22_ZH_MT_DESC_TITLE,
+    # MIRACL topics
     'miracl-v1.0-ar-dev': JTopics.MIRACL_V10_AR_DEV,
     'miracl-v1.0-bn-dev': JTopics.MIRACL_V10_BN_DEV,
     'miracl-v1.0-en-dev': JTopics.MIRACL_V10_EN_DEV,
