@@ -25,7 +25,7 @@ from pyserini.output_writer import OutputFormat, get_output_writer
 from pyserini.pyclass import autoclass
 from pyserini.query_iterator import get_query_iterator, TopicsFormat
 from pyserini.search import JDisjunctionMaxQueryGenerator
-from . import LuceneImpactSearcher, LuceneSearcher
+from . import LuceneImpactSearcher, LuceneSearcher, SlimSearcher
 from .reranker import ClassifierType, PseudoRelevanceClassifierReranker
 
 
@@ -77,6 +77,7 @@ def set_bm25_parameters(searcher, index, k1=None, b=None):
 def define_search_args(parser):
     parser.add_argument('--index', type=str, metavar='path to index or index name', required=True,
                         help="Path to Lucene index or name of prebuilt index.")
+    parser.add_argument('--encoded-corpus', type=str, default=None, help="path to stored sparse vectors")
 
     parser.add_argument('--impact', action='store_true', help="Use Impact.")
     parser.add_argument('--encoder', type=str, default=None, help="encoder name")
@@ -159,9 +160,15 @@ if __name__ == "__main__":
             searcher = LuceneSearcher.from_prebuilt_index(args.index)
     elif args.impact:
         if os.path.exists(args.index):
-            searcher = LuceneImpactSearcher(args.index, args.encoder, args.min_idf)
+            if args.encoded_corpus is not None:
+                searcher = SlimSearcher(args.encoded_corpus, args.index, args.encoder, args.min_idf)
+            else:
+                searcher = LuceneImpactSearcher(args.index, args.encoder, args.min_idf)
         else:
-            searcher = LuceneImpactSearcher.from_prebuilt_index(args.index, args.encoder, args.min_idf)
+            if args.encoded_corpus is not None:
+                searcher = SlimSearcher.from_prebuilt_index(args.encoded_corpus, args.index, args.encoder, args.min_idf)
+            else:
+                searcher = LuceneImpactSearcher.from_prebuilt_index(args.index, args.encoder, args.min_idf)
 
     if args.language != 'en':
         searcher.set_language(args.language)
